Django heaven
-------------

Django heaven brings structure and order to your Django applications.


Functionality:
_________
1) ORM queries in separate functions with logging and custom error handling
2) Responses with similar structure and logging support


Installation:
___________
- pip install django-heaven

